@@ -1,9 +1,9 @@
 
-from wofry.propagator.propagators2D.fraunhofer import Fraunhofer2D
-from wofry.propagator.propagators2D.fresnel import Fresnel2D
-from wofry.propagator.propagators2D.fresnel_convolution import FresnelConvolution2D
-from wofry.propagator.propagators2D.integral import Integral2D
-from wofry.propagator.propagators2D.fresnel_zoom_xy import FresnelZoomXY2D
+from wofryimpl.propagator.propagators2D.fraunhofer import Fraunhofer2D
+from wofryimpl.propagator.propagators2D.fresnel import Fresnel2D
+from wofryimpl.propagator.propagators2D.fresnel_convolution import FresnelConvolution2D
+from wofryimpl.propagator.propagators2D.integral import Integral2D
+from wofryimpl.propagator.propagators2D.fresnel_zoom_xy import FresnelZoomXY2D
 from wofry.propagator.propagator import PropagationManager
 
 def initialize_default_propagator_2D():
